# R script
# Transforms ALE and Simulation results to R datafile
# author: Xavier Devroey

require(sqldf)

# ------------------------------
# Functions definition
# ------------------------------

getCleanSimulationData <- function(randomdata){
  request <- "SELECT model, random, mutantorder, mutantts AS mutant, delta, epsilon, ((timeinms +1) * 1.0) / 1000 as timeinsec, failednbruns AS killed
    FROM randomdata
    WHERE run IN (11, 12, 13)"
  run1 <- sqldf(request)
  
  request <- "SELECT model, random,  mutantorder , mutantts AS mutant, delta, epsilon, ((timeinms +1) * 1.0) / 1000 as timeinsec, failednbruns AS killed
    FROM randomdata
    WHERE run IN (21, 22, 23)"
  run2 <- sqldf(request)
  
  request <- "SELECT model, random,  mutantorder , mutantts AS mutant, delta, epsilon, ((timeinms +1) * 1.0) / 1000 as timeinsec, failednbruns AS killed
    FROM randomdata
    WHERE run IN (31, 32, 33)"
  run3 <- sqldf(request)
  
  request <- "SELECT model, random,  mutantorder , mutantts AS mutant, delta, epsilon, ((timeinms +1) * 1.0) / 1000 as timeinsec, failednbruns AS killed
    FROM randomdata
    WHERE run IN (41, 42, 43)"
  run4 <- sqldf(request)
  
  run1$random[run1$random == "random-weak"] <- "WM RS1"
  run1$random[run1$random == "biased-weak"] <- "WM BS1"
  run1$random[run1$random == "biased-strong"] <- "SM BS1"
  
  run2$random[run2$random == "random-weak"] <- "WM RS2"
  run2$random[run2$random == "biased-weak"] <- "WM BS2"
  run2$random[run2$random == "biased-strong"] <- "SM BS2"
  
  run3$random[run3$random == "random-weak"] <- "WM RS3"
  run3$random[run3$random == "biased-weak"] <- "WM BS3"
  run3$random[run3$random == "biased-strong"] <- "SM BS3"
  
  run4$random[run4$random == "random-weak"] <- "WM RS4"
  run4$random[run4$random == "biased-weak"] <- "WM BS4"
  run4$random[run4$random == "biased-strong"] <- "SM BS4"
  
  return(rbind(run1, run2, run3, run4))
}

getCleanALEWMData <- function(exactdata){
  request <- "SELECT model, mutant, mutantorder , -1.0 AS delta, -1.0 AS epsilon, timeinsec + 0.001 as timeinsec, 'WM ALE' AS random, 1 AS killed
    FROM exactdata
    WHERE mutant LIKE '%.weak' "
  exactruns <- sqldf(request)
  return(exactruns)
}

getCleanALESMData <- function(exactdata){
  request <- "SELECT model, mutant,  mutantorder ,  -1.0 AS delta, -1.0 AS epsilon, timeinsec + 0.001 as timeinsec, 'SM ALE' AS random, 1 AS killed
    FROM exactdata
    WHERE mutant LIKE '%.strong' "
  exactruns <- sqldf(request)
  return(exactruns)
}

prettyPrint <- function(allRuns){
  allRuns$random <- factor(allRuns$random, levels = c("WM RS1", "WM RS2", "WM RS3", "WM RS4",
                                                      "WM BS1", "WM BS2", "WM BS3", "WM BS4",
                                                      "WM ALE", 
                                                      "SM BS1", "SM BS2", "SM BS3", "SM BS4",
                                                      "SM ALE"))
  
  allRuns$modelname[allRuns$model == "svm"] <- "S.V.Mach."
  allRuns$modelname[allRuns$model == "cpterminal"] <- "C.P.Term."  
  allRuns$modelname[allRuns$model == "minepump"] <- "Minepump"  
  allRuns$modelname[allRuns$model == "claroline"] <- "Claroline"
  allRuns$modelname[allRuns$model == "elsaRR"] <- "Elsa-RR"
  allRuns$modelname[allRuns$model == "elsaRRN"] <- "Elsa-RRN"
  allRuns$modelname[allRuns$model == "ageRR"] <- "AGE-RR"
  allRuns$modelname[allRuns$model == "ageRRN"] <- "AGE-RRN"
  allRuns$modelname[allRuns$model == "ts-f5e050b4-7767-4d96-9160-fa51184efff0"] <- "Random 1"
  allRuns$modelname[allRuns$model == "ts-62e92b35-b095-4942-a370-507615469463"] <- "Random 2"
  allRuns$modelname[allRuns$model == "ts-51d69eaf-3bd1-40af-aef0-983d75dc673e"] <- "Random 3"
  allRuns$modelname[allRuns$model == "ts-6cc2cfa6-f302-44da-8482-8ecb045fd8d9"] <- "Random 4"
  
  allRuns$modelname <- factor(allRuns$modelname, levels = c("S.V.Mach.", "C.P.Term.", "Minepump", "Claroline", "Elsa-RR", 
                                                    "Elsa-RRN", "AGE-RR", "AGE-RRN", "Random 1", "Random 2", "Random 3", "Random 4"))
  
  allRuns$modelfamily[allRuns$model == "svm"] <- "Embedded syst."
  allRuns$modelfamily[allRuns$model == "cpterminal"] <- "Embedded syst."  
  allRuns$modelfamily[allRuns$model == "minepump"] <- "Embedded syst."  
  allRuns$modelfamily[allRuns$model == "claroline"] <- "Web-application"
  allRuns$modelfamily[allRuns$model == "elsaRR"] <- "Web-application"
  allRuns$modelfamily[allRuns$model == "elsaRRN"] <- "Web-application"
  allRuns$modelfamily[allRuns$model == "ageRR"] <- "Web-application"
  allRuns$modelfamily[allRuns$model == "ageRRN"] <- "Web-application"
  allRuns$modelfamily[allRuns$model == "ts-f5e050b4-7767-4d96-9160-fa51184efff0"] <- "Random"
  allRuns$modelfamily[allRuns$model == "ts-62e92b35-b095-4942-a370-507615469463"] <- "Random"
  allRuns$modelfamily[allRuns$model == "ts-51d69eaf-3bd1-40af-aef0-983d75dc673e"] <- "Random"
  allRuns$modelfamily[allRuns$model == "ts-6cc2cfa6-f302-44da-8482-8ecb045fd8d9"] <- "Random"
  
  allRuns$modelfamily <- factor(allRuns$modelfamily, levels = c("Embedded syst.", "Web-application", "Random"))
  
  return(allRuns)
}

# ------------------------------
# Main function definition
# ------------------------------

main <- function(args){
  if(length(args) < 3){
    stop("Format: makedataframe.r <simulation.csv> <ale.csv> <output.rds>\n", call=FALSE)
  }
  simulation <- read.csv(args[1], header = TRUE, sep = ',', quote = '', dec = ".", stringsAsFactors=FALSE)
  ale <- read.csv(args[2], header = TRUE, sep = ',', quote = '', dec = ".", stringsAsFactors=FALSE)

  df <- getCleanSimulationData(simulation)
  df <- rbind(df, getCleanALEWMData(ale))
  df <- rbind(df, getCleanALESMData(ale))
  
  df <- prettyPrint(df)
  
  # save dataframe
  saveRDS(df, file=args[3], ascii=TRUE)
}

# ------------------------------
# Program
# ------------------------------

args <- commandArgs(trailingOnly = TRUE)
main(args)
