# R script
# 
# author: Xavier Devroey

require(base)

# ------------------------------
# Functions definition
# ------------------------------

printPValue <- function(lst1, lst2){
  w = wilcox.test(lst1, lst2, paired=FALSE)
  pv = w$p.value
  if(is.nan(pv)) {
    pv = 1
  }
  stat = pv < 0.05
  if(pv < 2.2e-16){ 
    pv = "\\le 2.2e-16"
  } else { 
    pv = formatC(pv,digits=3,format="e")
  }
  if(!stat) {
    cat("$\\mathbf{",pv,"}$",sep="")
  } else {
    cat("$",pv,"$",sep="")
  }
}

printWMPValues <- function(df){
  wsdf <- subset(df, startsWith(as.character(df$random),"WM") & !endsWith(as.character(df$random),"ALE"))
  wsaledf <- subset(df, as.character(df$random) == "WM ALE")
  models <- sort(unique(df$modelname))
  randoms <- sort(unique(wsdf$random))
  
  cat("\\begin{scriptsize}", "\n")
  cat("\\begin{tabular}{lcccccccc}", "\n")
  cat("\\hline", "\n")
  cat("\\textbf{Model} ")
  for(r in randoms){
    cat("& \\textbf{", r, "} ")
  }
  cat("\\\\", "\n")
  cat("\\hline", "\n")
  for(m in models){
    cat(m, " ")
    for(r in randoms){
      mdf <- subset(wsdf, (wsdf$modelname == m) & (wsdf$random == r))
      mwsaledf <- subset(wsaledf, wsaledf$modelname == m)
      cat(" & ")
      printPValue(mdf$timeinsec, mwsaledf$timeinsec)
    }
    cat("\\\\", "\n")
  }  
  cat("\\hline", "\n")
  cat("\\end{tabular}", "\n")
  cat("\\end{scriptsize}", "\n")
}

printSMPValues <- function(df){
  wsdf <- subset(df, startsWith(as.character(df$random),"SM") & !endsWith(as.character(df$random),"ALE"))
  wsaledf <- subset(df, as.character(df$random) == "SM ALE")
  models <- sort(unique(df$modelname))
  randoms <- sort(unique(wsdf$random))
  
  cat("\\begin{scriptsize}", "\n")
  cat("\\begin{tabular}{lcccccccc}", "\n")
  cat("\\hline", "\n")
  cat("\\textbf{Model} ")
  for(r in randoms){
    cat("& \\textbf{", r, "} ")
  }
  cat("\\\\", "\n")
  cat("\\hline", "\n")
  for(m in models){
    cat(m, " ")
    for(r in randoms){
      mdf <- subset(wsdf, (wsdf$modelname == m) & (wsdf$random == r))
      mwsaledf <- subset(wsaledf, wsaledf$modelname == m)
      cat(" & ")
      printPValue(mdf$timeinsec, mwsaledf$timeinsec)
    }
    cat("\\\\", "\n")
  }  
  cat("\\hline", "\n")
  cat("\\end{tabular}", "\n")
  cat("\\end{scriptsize}", "\n")
}

# ------------------------------
# Main function definition
# ------------------------------

main <- function(args){
  if(length(args) < 2){
    stop("Format: makeworstplot.r <data.rds> <output.pdf>\n", call=FALSE)
  }
  df <- readRDS(args[1])
  outputFile <- args[2]
  unlink(outputFile)
  sink(outputFile, append = TRUE, split = TRUE)
  printWMPValues(df)
  printSMPValues(df)
  sink()
}

# ------------------------------
# Program
# ------------------------------

args <- commandArgs(trailingOnly = TRUE)
main(args)
