# R script
# 
# author: Xavier Devroey

require(base)
require(tcltk)
library(ggplot2)

# ------------------------------
# Main function definition
# ------------------------------

main <- function(args){
  if(length(args) < 2){
    stop("Format: makerecallplot.r <data.rds> <output.pdf>\n", call=FALSE)
  }
  df <- readRDS(args[1])
  outputFile <- args[2]
  # Filter df to keep RS and BS only and exclude equiv
  randomData <- df[!grepl("ALE", as.character(df$random)) & (as.character(df$mutantorder) != "equiv"),]
  # Aggregate data on model and random columns and compute mean
  agg <- aggregate(killed ~ model + random, randomData, mean)
  
  # Draw plot
  pdf(outputFile, height=2, width=5)
  p <- ggplot(agg, aes(x=random, y=killed, fill=factor(random))) 
  p + theme(axis.text.x = element_text(angle=90)) + geom_boxplot() + xlab("") + ylab("Recall") + guides(fill=FALSE)
}

# ------------------------------
# Program
# ------------------------------

args <- commandArgs(trailingOnly = TRUE)
main(args)
dev.off( )