# R script
# 
# author: Xavier Devroey

require(tcltk)
library(ggplot2)

# ------------------------------
# Main function definition
# ------------------------------

main <- function(args){
  if(length(args) < 2){
    stop("Format: maketimeplot.r <data.rds> <output.pdf>\n", call=FALSE)
  }
  df <- readRDS(args[1])
  outputFile <- args[2]
  
  # Filter df to exclude equiv
  randomData <- df[as.character(df$mutantorder) != "equiv",]
  
  # Draw plot
  pdf(outputFile, height=6, width=12)
  p <- ggplot(randomData, aes(x=random, y=timeinsec, fill=factor(random))) 
  p + theme(axis.text.x = element_text(angle=90)) + geom_boxplot(outlier.size=0.5, outlier.shape=21) + scale_y_log10() + facet_wrap(~ model) + xlab("") + ylab("Time in seconds (log scale)") + guides(fill=FALSE)
}

# ------------------------------
# Program
# ------------------------------

args <- commandArgs(trailingOnly = TRUE)
main(args)
dev.off( )
